@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000031';
+$LWP::ConsoleLogger::VERSION = '0.000032';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use HTML::Restrict qw();
@@ -336,6 +336,8 @@ sub _get_content {
     return unless $content;
 
     my $content_type = $r->header('Content-Type');
+    return $content unless $content_type;
+
     my ( $type, $subtype ) = apply { lc $_ } parse_mime_type($content_type);
     if (   ( $type ne 'text' )
         && ( none { $_ eq $subtype } ( 'javascript', 'html', 'json', 'xml' ) )
@@ -411,6 +413,14 @@ sub _parse_body {
     my $content_type = shift;
     my $t            = shift;
 
+    # Is this maybe JSON?
+    try {
+        decode_json($content);
+
+        # If we get this far, it's valid JSON.
+        $content_type = 'application/json';
+    };
+
     # nothing to do here
     unless ($content_type) {
         $t->row($content);
@@ -510,7 +520,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000031
+version 0.000032
 
 =head1 SYNOPSIS
 
